@@ -55,7 +55,7 @@ p_netk_get_cardinal (Window xwindow, Atom atom, int *val)
     result =
         XGetWindowProperty (gdk_display, xwindow, atom, 0, G_MAXLONG, False,
                             XA_CARDINAL, &type, &format, &nitems,
-                            &bytes_after, (guchar **) & num);
+                            &bytes_after, (guchar **)&num);
     err = p_netk_error_trap_pop ();
     if (err != Success || result != Success)
         return FALSE;
@@ -93,7 +93,7 @@ p_netk_get_wm_state (Window xwindow)
     result =
         XGetWindowProperty (gdk_display, xwindow, wm_state, 0, G_MAXLONG,
                             False, wm_state, &type, &format, &nitems,
-                            &bytes_after, (guchar **) & num);
+                            &bytes_after, (guchar **)&num);
     err = p_netk_error_trap_pop ();
     if (err != Success || result != Success)
         return retval;
@@ -128,7 +128,7 @@ p_netk_get_window (Window xwindow, Atom atom, Window * val)
     result =
         XGetWindowProperty (gdk_display, xwindow, atom, 0, G_MAXLONG, False,
                             XA_WINDOW, &type, &format, &nitems, &bytes_after,
-                            (guchar **) & w);
+                            (guchar **)&w);
     err = p_netk_error_trap_pop ();
     if (err != Success || result != Success)
         return FALSE;
@@ -163,7 +163,7 @@ p_netk_get_pixmap (Window xwindow, Atom atom, Pixmap * val)
     result =
         XGetWindowProperty (gdk_display, xwindow, atom, 0, G_MAXLONG, False,
                             XA_PIXMAP, &type, &format, &nitems, &bytes_after,
-                            (guchar **) & w);
+                            (guchar **)&w);
     err = p_netk_error_trap_pop ();
     if (err != Success || result != Success)
         return FALSE;
@@ -198,7 +198,7 @@ p_netk_get_atom (Window xwindow, Atom atom, Atom * val)
     result =
         XGetWindowProperty (gdk_display, xwindow, atom, 0, G_MAXLONG, False,
                             XA_ATOM, &type, &format, &nitems, &bytes_after,
-                            (guchar **) & a);
+                            (guchar **)&a);
     err = p_netk_error_trap_pop ();
     if (err != Success || result != Success)
         return FALSE;
@@ -283,7 +283,7 @@ p_netk_get_string_property_latin1 (Window xwindow, Atom atom)
     result =
         XGetWindowProperty (gdk_display, xwindow, atom, 0, G_MAXLONG, False,
                             XA_STRING, &type, &format, &nitems, &bytes_after,
-                            (guchar **) & str);
+                            (guchar **)&str);
 
     err = p_netk_error_trap_pop ();
     if (err != Success || result != Success)
@@ -322,7 +322,7 @@ p_netk_get_utf8_property (Window xwindow, Atom atom)
     result =
         XGetWindowProperty (gdk_display, xwindow, atom, 0, G_MAXLONG, False,
                             utf8_string, &type, &format, &nitems,
-                            &bytes_after, (guchar **) & val);
+                            &bytes_after, (guchar **)&val);
     err = p_netk_error_trap_pop ();
 
     if (err != Success || result != Success)
@@ -369,7 +369,7 @@ p_netk_get_window_list (Window xwindow, Atom atom, Window ** windows,
     result =
         XGetWindowProperty (gdk_display, xwindow, atom, 0, G_MAXLONG, False,
                             XA_WINDOW, &type, &format, &nitems, &bytes_after,
-                            (guchar **) & data);
+                            (guchar **)&data);
     err = p_netk_error_trap_pop ();
     if (err != Success || result != Success)
         return FALSE;
@@ -407,7 +407,7 @@ p_netk_get_atom_list (Window xwindow, Atom atom, Atom ** atoms, int *len)
     result =
         XGetWindowProperty (gdk_display, xwindow, atom, 0, G_MAXLONG, False,
                             XA_ATOM, &type, &format, &nitems, &bytes_after,
-                            (guchar **) & data);
+                            (guchar **)&data);
     err = p_netk_error_trap_pop ();
     if (err != Success || result != Success)
         return FALSE;
@@ -446,7 +446,7 @@ p_netk_get_cardinal_list (Window xwindow, Atom atom, gulong ** cardinals,
     result =
         XGetWindowProperty (gdk_display, xwindow, atom, 0, G_MAXLONG, False,
                             XA_CARDINAL, &type, &format, &nitems,
-                            &bytes_after, (guchar **) & nums);
+                            &bytes_after, (guchar **)&nums);
     err = p_netk_error_trap_pop ();
     if (err != Success || result != Success)
         return FALSE;
@@ -473,13 +473,13 @@ p_netk_get_utf8_list (Window xwindow, Atom atom)
     int format;
     gulong nitems;
     gulong bytes_after;
-    char *val;
+    gchar *val;
     int err, result;
     Atom utf8_string;
     char **retval;
     int i;
     int n_strings;
-    char *p;
+    gchar *p;
 
     utf8_string = p_netk_atom_get ("UTF8_STRING");
 
@@ -489,7 +489,7 @@ p_netk_get_utf8_list (Window xwindow, Atom atom)
     result =
         XGetWindowProperty (gdk_display, xwindow, atom, 0, G_MAXLONG, False,
                             utf8_string, &type, &format, &nitems,
-                            &bytes_after, (guchar **) & val);
+                            &bytes_after, (guchar **)&val);
     err = p_netk_error_trap_pop ();
 
     if (err != Success || result != Success)
@@ -506,7 +506,7 @@ p_netk_get_utf8_list (Window xwindow, Atom atom)
      * property is nul-separated
      */
     i = 0;
-    n_strings = 1;
+    n_strings = 0;
     while (i < nitems)
     {
         if (val[i] == '\0')
@@ -514,6 +514,11 @@ p_netk_get_utf8_list (Window xwindow, Atom atom)
         ++i;
     }
 
+    if (val[nitems - 1] != '\0')
+    {
+        ++n_strings;
+    }
+
     /* we're guaranteed that val has a nul on the end
      * by XGetWindowProperty
      */
@@ -1268,7 +1273,7 @@ read_rgb_icon (Window xwindow, int ideal_width, int ideal_height,
         XGetWindowProperty (gdk_display, xwindow,
                             p_netk_atom_get ("_NET_WM_ICON"), 0, G_MAXLONG,
                             False, XA_CARDINAL, &type, &format, &nitems,
-                            &bytes_after, ((guchar **) & data));
+                            &bytes_after, (guchar **)&data);
 
     err = p_netk_error_trap_pop ();
 
@@ -1562,7 +1567,7 @@ get_kwm_win_icon (Window xwindow, Pixmap * pixmap, Pixmap * mask)
                             p_netk_atom_get ("KWM_WIN_ICON"), 0, G_MAXLONG,
                             False, p_netk_atom_get ("KWM_WIN_ICON"), &type,
                             &format, &nitems, &bytes_after,
-                            (guchar **) & icons);
+                            (guchar **)&icons);
 
     err = p_netk_error_trap_pop ();
     if (err != Success || result != Success)
@@ -2376,11 +2381,10 @@ p_netk_get_desktop_margins (Screen * xscreen, p_DesktopMargins * margins)
          (gdk_display, RootWindowOfScreen (xscreen),
           p_netk_atom_get ("_NET_WORKAREA"), 0L, 4 * number_of_desktops,
           False, XA_CARDINAL, &real_type, &real_format, &items_read,
-          &items_left, (unsigned char **) &data) == Success)
+          &items_left, (guchar **)&data) == Success)
         && (items_read >= 4 * number_of_desktops))
     {
-        int current_desktop;
-
+        int current_desktop;	
         if ((p_netk_get_cardinal
              (RootWindowOfScreen (xscreen),
               p_netk_atom_get ("_NET_CURRENT_DESKTOP"), &current_desktop))
@@ -2417,13 +2421,14 @@ p_netk_get_desktop_margins (Screen * xscreen, p_DesktopMargins * margins)
               (gdk_display, RootWindowOfScreen (xscreen),
                p_netk_atom_get ("GNOME_PANEL_DESKTOP_AREA"), 0L, 4L, False,
                XA_CARDINAL, &real_type, &real_format, &items_read,
-               &items_left, (unsigned char **) &data) == Success)
+               &items_left, (guchar **)&data) == Success)
              && (items_read >= 4))
     {
         margins->left = data[0];
         margins->top = data[1];
         margins->right = data[2];
         margins->bottom = data[3];
+	
         XFree (data);
         return TRUE;
     }
@@ -2450,7 +2455,7 @@ p_netk_set_desktop_margins (Window xwindow, p_DesktopMargins * margins)
     *ptr++ = margins->top;
     *ptr++ = margins->bottom;
     XChangeProperty (gdk_display, xwindow, p_netk_atom_get ("_NET_WM_STRUT"),
-                     XA_CARDINAL, 32, PropModeReplace, (unsigned char *) data,
+                     XA_CARDINAL, 32, PropModeReplace, (guchar *) data,
                      4);
     g_free (data);
 }
